@@ -2,6 +2,7 @@ import asyncio
 import copy
 import json
 import os
+import sys
 from json.decoder import JSONDecodeError
 from typing import Any, Dict, List, Optional, Union
 
@@ -12,13 +13,13 @@ from pymongo.collection import Collection
 from watchdog import observers
 from watchdog.events import FileSystemEvent, FileSystemEventHandler
 
-from kekmonitors.config import COMMANDS, ERRORS, Config, LogConfig
 from kekmonitors.comms.msg import Cmd, Response, badResponse, okResponse
 from kekmonitors.comms.server import Server
+from kekmonitors.config import COMMANDS, ERRORS, Config, LogConfig
+from kekmonitors.exceptions import AlreadyRegisteredError
 from kekmonitors.shoe_manager import ShoeManager
 from kekmonitors.shoe_stuff import Shoe
 from kekmonitors.utils.tools import get_file_if_exist_else_create, get_logger
-import sys
 
 if sys.version_info[1] > 6:
     import uvloop
@@ -31,7 +32,7 @@ def register_as(_type: str, name: str, path: str, client: Collection):
         client[_type].insert_one({"name": name, "path": path})
     else:
         if existing["path"] != path:
-            raise Exception(
+            raise AlreadyRegisteredError(
                 f"Trying to register new {_type} ({name}) when it already exists in the database with a different path: {existing['path']}"
             )
 
@@ -52,7 +53,7 @@ class Common(Server, FileSystemEventHandler):
         )
         self.client_logger = get_logger(log_config)
 
-        self.delay = int(config["Options"]["loop_delay"])
+        self.delay = float(config["Options"]["loop_delay"])
 
         if sys.version_info[1] > 6:
             asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
@@ -532,7 +533,7 @@ class Common(Server, FileSystemEventHandler):
     async def main(self):
         pass
 
-    def check_shoe(self, shoe: Shoe):
+    def shoe_check(self, shoe: Shoe):
         """Searches the database for the given, updating it if found or adding it if not found. Also updates the last_seen timestamp.
 
         Args:
