@@ -1,8 +1,8 @@
 import asyncio
 import copy
-from datetime import datetime
 import json
 import traceback
+from datetime import datetime
 from typing import Optional
 
 import discord
@@ -18,7 +18,9 @@ from kekmonitors.webhook_manager import WebhookManager
 
 
 class BaseMonitor(Common, NetworkUtils):
-    def __init__(self, config: Config = Config(), **kwargs):
+    def __init__(self, config: Config = None, **kwargs):
+        if not config:
+            config = Config()
         config["OtherConfig"]["socket_name"] = f"Monitor.{self.get_class_name()}"
 
         super().__init__(config, **kwargs)
@@ -62,11 +64,16 @@ class BaseMonitor(Common, NetworkUtils):
                 except:
                     self.general_logger.exception("")
                     if self.crash_webhook:
+                        content = f"```{traceback.format_exc()}\n\nRestarting in {self.delay} seconds.```"
+                        if len(content) > 2000:
+                            content = f"```Stacktrace too long -- please view logs.\n\nRestarting in {self.delay} seconds.```"
                         data = json.dumps(
                             {
-                                "content": f"{self.class_name} has crashed:\n{traceback.format_exc()}\nRestarting in {self.delay} secs."[
-                                    :2000
-                                ]
+                                "content": content,
+                                "username": f"Monitor {self.class_name}",
+                                "avatar_url": self.config["WebhookConfig"][
+                                    "provider_icon"
+                                ],
                             }
                         )
                         await self.client.fetch(
