@@ -15,9 +15,10 @@ from watchdog import observers
 from watchdog.events import FileSystemEvent, FileSystemEventHandler
 
 import kekmonitors.utils.tools
-from kekmonitors.config import COMMANDS, ERRORS, Config, LogConfig
 from kekmonitors.comms.msg import Cmd, Response, badResponse, okResponse
 from kekmonitors.comms.server import Server
+from kekmonitors.config import COMMANDS, ERRORS, Config, LogConfig
+from kekmonitors.discord_embeds import get_mm_crash_embed
 
 if sys.version_info[1] > 6:
     import uvloop
@@ -33,7 +34,9 @@ def get_parent_directory(src: str) -> str:
 class MonitorManager(Server, FileSystemEventHandler):
     """This can be used to manage monitors/scrapers with an external api."""
 
-    def __init__(self, config: Config = Config()):
+    def __init__(self, config: Config = None):
+        if not config:
+            config = Config()
         # set default name if not already set in config
         if not config["OtherConfig"]["socket_name"]:
             config["OtherConfig"]["socket_name"] = f"Executable.MonitorManager"
@@ -495,11 +498,34 @@ class MonitorManager(Server, FileSystemEventHandler):
                         if monitor.returncode:
                             self.general_logger.warning(log)
                             if self.config["WebhookConfig"]["crash_webhook"]:
-                                data = {"content": log}
-                                await self.client.fetch(
+                                embed = get_mm_crash_embed(
+                                    "Monitor " + class_name,
+                                    monitor.returncode,
+                                    monitor.pid,
+                                )
+                                ts = datetime.now().strftime(
+                                    self.config["WebhookConfig"]["timestamp_format"]
+                                )
+
+                                embed.set_footer(
+                                    text=f"{self.config['WebhookConfig']['provider']} | {ts}",
+                                    icon_url=self.config["WebhookConfig"][
+                                        "provider_icon"
+                                    ],
+                                )
+                                data = json.dumps(
+                                    {
+                                        "embeds": [embed.to_dict()],
+                                        "username": "MonitorManager process watcher",
+                                        "avatar_url": self.config["WebhookConfig"][
+                                            "provider_icon"
+                                        ],
+                                    }
+                                )
+                                r = await self.client.fetch(
                                     self.config["WebhookConfig"]["crash_webhook"],
                                     method="POST",
-                                    body=json.dumps(data),
+                                    body=data,
                                     headers={"content-type": "application/json"},
                                     raise_error=False,
                                 )
@@ -519,11 +545,34 @@ class MonitorManager(Server, FileSystemEventHandler):
                         if scraper.returncode:
                             self.general_logger.warning(log)
                             if self.config["WebhookConfig"]["crash_webhook"]:
-                                data = {"content": log}
-                                await self.client.fetch(
+                                embed = get_mm_crash_embed(
+                                    "Scraper " + class_name,
+                                    scraper.returncode,
+                                    scraper.pid,
+                                )
+                                ts = datetime.now().strftime(
+                                    self.config["WebhookConfig"]["timestamp_format"]
+                                )
+
+                                embed.set_footer(
+                                    text=f"{self.config['WebhookConfig']['provider']} | {ts}",
+                                    icon_url=self.config["WebhookConfig"][
+                                        "provider_icon"
+                                    ],
+                                )
+                                data = json.dumps(
+                                    {
+                                        "embeds": [embed.to_dict()],
+                                        "username": "MonitorManager process watcher",
+                                        "avatar_url": self.config["WebhookConfig"][
+                                            "provider_icon"
+                                        ],
+                                    }
+                                )
+                                r = await self.client.fetch(
                                     self.config["WebhookConfig"]["crash_webhook"],
                                     method="POST",
-                                    body=json.dumps(data),
+                                    body=data,
                                     headers={"content-type": "application/json"},
                                     raise_error=False,
                                 )
@@ -662,7 +711,10 @@ class MonitorManager(Server, FileSystemEventHandler):
             start = self.monitor_processes[class_name]["start"].strftime(
                 "%m/%d/%Y, %H:%M:%S"
             )
-            process_status[class_name] = {"Started at": start}
+            process_status[class_name] = {
+                "Started at": start,
+                "PID": self.monitor_processes[class_name]["process"].pid,
+            }
         sockets_status = {}
         # for class_name in self.monitor_sockets:
         # sockets_status[class_name] = {class_name: self.monitor_sockets[class_name]}
@@ -680,7 +732,10 @@ class MonitorManager(Server, FileSystemEventHandler):
             start = self.scraper_processes[class_name]["start"].strftime(
                 "%m/%d/%Y, %H:%M:%S"
             )
-            process_status[class_name] = {"Started at": start}
+            process_status[class_name] = {
+                "Started at": start,
+                "PID": self.scraper_processes[class_name]["process"].pid,
+            }
         sockets_status = {}
         # for class_name in self.scraper_sockets:
         # sockets_status[class_name] = {class_name: self.scraper_sockets[class_name]}
