@@ -8,8 +8,8 @@ import sys
 from datetime import timezone
 from typing import Dict, List
 
-from kekmonitors.config import ERRORS, Config, LogConfig
 from kekmonitors.comms.msg import Cmd, Response, badResponse, okResponse
+from kekmonitors.config import ERRORS, Config, LogConfig
 
 if sys.version_info[1] < 9:
 
@@ -141,11 +141,14 @@ def chunks(lst, n):
         yield lst[i : i + n]
 
 
-def make_default_executable(_class, config: Config = Config()):
+def make_default_executable(_class, config: Config = None):
     """
     Start the specified class with an optional config, adding support to default cli options
     (needed for the monitor manager). ***Needs to be inside `if __name__=="__main__":`***
     """
+    if not config:
+        config = Config()
+
     if sys.version_info[1] < 9:
         boolAction = BooleanOptionalAction  # type: ignore
     else:
@@ -157,7 +160,7 @@ def make_default_executable(_class, config: Config = Config()):
         "-d",
         "--delay",
         default=config["Options"]["loop_delay"],
-        type=int,
+        type=float,
         help=f"Specify a delay for the loop. (default: {config['Options']['loop_delay']})",
     )
     parser.add_argument(
